@@ -38,6 +38,7 @@
 #' data(peru.df)
 #' modcheck(lm(BP ~ weight, data = peru.df))
 #' 
+#' @importFrom methods is
 #' @export modcheck 
 modcheck = function(x, ...) {
   UseMethod("modcheck")
@@ -67,7 +68,7 @@ modcheck.lm = function(x, plotOrder = 1:4,
                                       xaxs = "r", yaxs = "r", pty = "s",
                                       mai = c(0.2, 0.2, 0.05, 0.05)),
                        ...){
-  if (missing(x) || (class(x) != "lm")) 
+  if (missing(x) || !is(x, "lm")) 
     stop("missing or incorrect lm object")
   
   if(!all(plotOrder %in% 1:4)){
@@ -75,6 +76,7 @@ modcheck.lm = function(x, plotOrder = 1:4,
   }
   
   oldPar = par(parVals)
+  on.exit(par(oldPar))
   
   Plots = c(eovcheck, normcheck, normcheck, cooks20x)[plotOrder]
   
@@ -105,6 +107,4 @@ modcheck.lm = function(x, plotOrder = 1:4,
       do.call(what = cooks20x, args = args$cooks20x)
     }
   }
-  
-  on.exit(par(oldPar))
 }
